@@ -31,11 +31,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 
-#include <libgames-support/games-gridframe.h>
 #include <libgames-support/games-scores.h>
-#include <libgames-support/games-stock.h>
-#include <libgames-support/games-pause-action.h>
-#include <libgames-support/games-fullscreen-action.h>
 
 #include "main.h"
 #include "properties.h"
@@ -45,6 +41,10 @@
 #include "preferences.h"
 #include "scoreboard.h"
 #include "warp.h"
+#include "games-gridframe.h"
+#include "games-pause-action.h"
+#include "games-fullscreen-action.h"
+#include "games-stock.h"
 
 #include <clutter-gtk/clutter-gtk.h>
 #include <clutter/clutter.h>
